from typing import Dict

from pyspark.sql import SparkSession
import logging

logger = logging.getLogger()


def createSession(name: str, spark_jars: Dict[str, str], mongodb_uri: str = "") -> SparkSession:
    session = None
    try:
        jars = list(spark_jars.values())
        jars = ",".join(jars)
        print(jars)
        session = SparkSession.builder \
            .appName(name) \
            .config("spark.hadoop.fs.s3a.impl", "org.apache.hadoop.fs.s3a.S3AFileSystem") \
            .config("spark.hadoop.fs.s3a.aws.credentials.provider",
                    "com.amazonaws.auth.DefaultAWSCredentialsProviderChain") \
            .config("spark.jars", jars) \
            .config("spark.executor.extraClassPath", jars) \
            .config("spark.driver.extraClassPath", jars) \
            .config("spark.mongodb.output.uri", mongodb_uri) \
            .getOrCreate()
        session._jsc.hadoopConfiguration().set("fs.s3a.impl", "org.apache.hadoop.fs.s3a.S3AFileSystem")
    except Exception as e:
        logger.error(f"Error creando sesion. {e}")
    finally:
        return session
