import time
import json
import logging
from typing import Any, Dict
from prefect import flow

from Pipeline.ETLProcess import ETLProcess


logger = logging.getLogger()

SPARK_JARS = {
    "AWS_CORE": "/opt/spark-jars/hadoop-aws-3.3.4.jar",
    "BUNDLE": "/opt/spark-jars/aws-java-sdk-bundle-1.12.431.jar",
    "COMMON": "/opt/spark-jars/hadoop-common-3.3.4.jar",
    "AWS_CLIENT": "/opt/spark-jars/hadoop-client-3.3.4.jar",
    "MONGO_CORE": "/opt/spark-jars/mongodb-driver-core-4.0.4.jar",
    "MONGO_CLIENT": "/opt/spark-jars/mongodb-driver-sync-4.0.4.jar",
    "MONGODB": "/opt/spark-jars/mongo-spark-connector_2.12-3.0.1.jar",
    "BSON": "/opt/spark-jars/bson-4.0.4.jar"
}

MONGODB_URI = "mongodb://bcom_spark_user:root@192.168.1.37:50001/bcom_spark"


@flow
def run_etl(config: Dict[str, Any]) -> None:
    start_time = time.time()
    etl_process = ETLProcess(config)
    # Conexion a Spark (LocalMode, StandAlone or Clúster)
    etl_process.init(SPARK_JARS, MONGODB_URI)

    # Primer task - (Reader) - Extraer los ficheros
    etl_process.reader(etl_process)

    # Segundo task - Setear esquema a las tablas
    etl_process.set_schema(etl_process)

    # Process - Insumo Gross (Ventas)
    ventas_flag = etl_process.process_gross.submit(etl_process, "VENTAS")

    # Process - Insumo Team (Equipos)
    teams_flag = etl_process.process_teams.submit(etl_process, "TEAMS")

    # Write - Insumo GROSS
    etl_process.write.submit(etl_process, "VENTAS", ventas_flag)
    # Write - Insumo TEAMS
    etl_process.write.submit(etl_process, "TEAMS", teams_flag)
    # Write - Insumo GOALS
    etl_process.write.submit(etl_process, "GOALS")
    # Write - Insumo PLANTA
    etl_process.write.submit(etl_process, "COMERCIAL_BASE")

    logger.info(f"Duración de ejecución del proceso ETL: {start_time - time.time()}")


if __name__ == "__main__":

    conf_path = "config.json"
    with open(conf_path) as f:
        conf = json.load(f)

    # Run ETL
    run_etl(conf)

